﻿using Hotline.FlowEngine.Notifies;
using Hotline.KnowledgeBase;
using Hotline.Settings;
using MediatR;

namespace Hotline.Application.Handlers.FlowEngine;

public class EndWorkflowHandler : INotificationHandler<EndWorkflowNotify>
{
    private readonly IKnowledgeDomainService _knowledgeDomainService;

    public EndWorkflowHandler(IKnowledgeDomainService knowledgeDomainService)
    {
        _knowledgeDomainService = knowledgeDomainService;
    }

    /// <summary>Handles a notification</summary>
    /// <param name="notification">The notification</param>
    /// <param name="cancellationToken">Cancellation token</param>
    public async Task Handle(EndWorkflowNotify notification, CancellationToken cancellationToken)
    {
        //知识审批收到此消息表示审批通过
        var workflow = notification.Workflow;
        switch (workflow.ModuleCode)
        {
            case WorkflowModuleConsts.KnowledgeAdd://新增
            case WorkflowModuleConsts.KnowledgeUpdate://修改
            case WorkflowModuleConsts.KnowledgeDelete://删除
                await _knowledgeDomainService.EndWorkKnowledge(workflow, cancellationToken);
                break;
        }
    }
}